#!/bin/bash
#
# Copyright (C) 2019 OX Software GmbH
# 
# This file is part of OX Automation.
#
# OX Automation is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# OX Automation is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with OX Automation. If not, see <http://www.gnu.org/licenses/>.
#
#
# Authors:
# Benedikt Kroening <benedikt.kroening@open-xchange.com>
#
set -e
SCRIPT_DIR="$( cd "$(dirname "$0")" ; pwd -P)"
# sourcing some commonly used functions and executing basic checks
source ${SCRIPT_DIR}/../../lib/common.bash
checkRootPrivileges
detectDistribution

 
# BALANCER_NAME=oxcluster
# BALANCER_HOST="https://localhost:8009"
# BALANCER_ROUTE=singlenode
# BALANCER_PRIORITY=50

## Help text
show_usage() {
echo -n "
  $0 [OPTIONS]

    Available options:
      -n | --name <name>     Balancer name
      -b | --balancer <host> Balancer host
      -p | --priority <n>    Load priority of the balancer
      -r | --route <route>   The backend route name used when setting the node up

"
}

### reading config from command line; overriding defaults
POSITIONAL=()
while [[ $# -gt 0 ]]
do
key="$1"

case $key in
    -h|--help)
    show_usage
    exit 0
    shift
    ;;
    --debug)
    echo "WARNING: Debug flag set (--debug)"
    set -x
    shift
    ;;
    -n|--name)
    BALANCER_NAME="$2"
    shift
    shift
    ;;

    # -f|--file)
    # FILE_NAME="$2"
    # shift
    # shift
    # ;;
    *) # unknown option
    echo "Unknonwn option: $1"
    POSITIONAL+=("$1") # save it in an array for later
    shift 
    ;;
esac
done
set -- "${POSITIONAL[@]}" # restore positional parameters

CERTIFICATE_PATH=/opt/open-xchange/certs

mkdir -p ${CERTIFICATE_PATH}


openssl genrsa -out ${CERTIFICATE_PATH}/frontend.key 4096
openssl req -new -subj "/C=DE/ST=NRW/L=Olpe/O=OE/CN=$(hostname -s)" -out ${CERTIFICATE_PATH}/frontend.csr -sha256 -key ${CERTIFICATE_PATH}/frontend.key
openssl x509 -req -in ${CERTIFICATE_PATH}/frontend.csr -days 365 -signkey ${CERTIFICATE_PATH}/frontend.key -out ${CERTIFICATE_PATH}/frontend.crt -outform PEM

#restartService ${HTTPD}